bayespy.inference.vmp.nodes.categorical_markov_chain.CategoricalMarkovChainDistribution.plates_from_parent
==========================================================================================================

.. currentmodule:: bayespy.inference.vmp.nodes.categorical_markov_chain

.. automethod:: CategoricalMarkovChainDistribution.plates_from_parent